@@ -1,6 +1,6 @@
 #! /usr/bin/env python3
 # SPDX-FileCopyrightText: 2022 geisserml <geisserml@gmail.com>
-# SPDX-License-Identifier: Apache-2.0 OR BSD-3-Clause
+# SPDX-License-Identifier: CC-BY-4.0
 
 import ctypes
 import argparse
@@ -22,7 +22,7 @@ def _merge_pdfs(input_paths):
 
 def parse_args():
     parser = argparse.ArgumentParser(
-        description = "Merge PDF files with PyPDFium2.",
+        description = "Merge PDF files with pypdfium2.",
     )
     parser.add_argument(
         'input_paths',
