@@ -2,10 +2,9 @@
 # SPDX-License-Identifier: Apache-2.0 OR BSD-3-Clause
 
 import logging
+import os
 from os.path import (
     join,
-    isdir,
-    isfile,
     dirname,
     abspath,
 )
@@ -15,9 +14,11 @@ lib_logger = logging.getLogger('pypdfium2')
 lib_logger.addHandler(logging.StreamHandler())
 
 
-TestDir = dirname(abspath(__file__))
+TestDir     = dirname(abspath(__file__))
+SourceTree  = dirname(TestDir)
 ResourceDir = join(TestDir,'resources')
-OutputDir = join(TestDir,'output')
+OutputDir   = join(TestDir,'output')
+
 
 class TestFiles:
     render = join(ResourceDir,'render.pdf')
@@ -27,15 +28,32 @@ class TestFiles:
     bookmarks_circular = join(ResourceDir,'bookmarks_circular.pdf')
     cropbox = join(ResourceDir,'cropbox.pdf')
     mediabox_missing = join(ResourceDir,'mediabox_missing.pdf')
+    nonascii = join(ResourceDir,'nonascii_tênfilechứakýtựéèáàçß 发短信.pdf')
+
+
+def iterate_testfiles(skip_encrypted=True):
+    
+    encrypted = (TestFiles.encrypted, )
+    
+    for attr_name in dir(TestFiles):
+        
+        if attr_name.startswith('_'):
+            continue
+        
+        member = getattr(TestFiles, attr_name)
+        if skip_encrypted and member in encrypted:
+            continue
+        
+        yield member
 
 
 def test_paths():
     
-    print(ResourceDir)
-    assert isdir(ResourceDir)
+    dirs = (TestDir, SourceTree, ResourceDir, OutputDir)
+    for dirpath in dirs:
+        print(dirpath)
+        assert os.path.isdir(dirpath)
     
-    for attr_name in dir(TestFiles):
-        if not attr_name.startswith('_'):
-            filepath = getattr(TestFiles, attr_name)
-            print(filepath)
-            assert isfile(filepath)
+    for filepath in iterate_testfiles(False):
+        print(filepath)
+        assert os.path.isfile(filepath)
